==> igniteui-angular-charts-17.2.1.tgz: package/esm5/lib/StepAreaSeries_combined.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { HorizontalAnchoredCategorySeries } from "./HorizontalAnchoredCategorySeries";
import { CategoryLineRasterizer } from "./CategoryLineRasterizer";
import { typeCast, Array_$type, runOn, markType } from "igniteui-angular-core";
import { ISortingAxis_$type } from "./ISortingAxis";
import { List$1 } from "igniteui-angular-core";
import { Path } from "igniteui-angular-core";
import { ScalerParams } from "./ScalerParams";
import { intDivide, isNaN_ } from "igniteui-angular-core";
import { AnchoredCategorySeriesView } from "./AnchoredCategorySeriesView";
import { Defaults } from "./Defaults";
/**
 * @hidden
 */
var StepAreaSeries = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(StepAreaSeries, _super);
    function StepAreaSeries() {
        var _this = _super.call(this) || this;
        _this.zf = null;
        _this.zf = new CategoryLineRasterizer();
        _this.ab = StepAreaSeries.$;
        return _this;
    }
    StepAreaSeries.prototype.bg = function () {
        return new StepAreaSeries();
    };
    StepAreaSeries.prototype.ch = function () {
        return new StepAreaSeriesView(this);
    };
    StepAreaSeries.prototype.o1 = function (a) {
        _super.prototype.o1.call(this, a);
        this.zg = a;
    };
    StepAreaSeries.prototype.get_ea = function () {
        return true;
    };
    StepAreaSeries.prototype.get_d9 = function () {
        return true;
    };
    StepAreaSeries.prototype.get_ff = function () {
        return true;
    };
    StepAreaSeries.prototype.get_ez = function () {
        return true;
    };
    StepAreaSeries.prototype.cn = function () {
        if (this.co == 0) {
            return 2;
        }
        return _super.prototype.cn.call(this);
    };
    StepAreaSeries.prototype.preferredCategoryMode = function (a) {
        return typeCast(ISortingAxis_$type, a) !== null ? 0 : 1;
    };
    StepAreaSeries.prototype.nk = function (a, b) {
        _super.prototype.nk.call(this, a, b);
        var c = b;
        c.de();
    };
    StepAreaSeries.prototype.zh = function (a, b, c, d, e) {
        if (b) {
            if (e) {
                if ((a & 1) == 0 || ((intDivide(a, 2)) + 1) >= c.f.count) {
                    return c.f._inner[(intDivide(a, 2))][0];
                }
                return c.f._inner[(intDivide(a, 2)) + 1][0];
            }
            return c.f._inner[(intDivide(a, 2))][0] + ((a & 1) == 1 ? -d : d);
        }
        if (e) {
            if ((a & 1) == 0 || ((intDivide(a, 2)) + 1) >= c.f.count) {
                return c.f._inner[(intDivide(a, 2))][0];
            }
            return c.f._inner[(intDivide(a, 2)) + 1][0];
        }
        return c.f._inner[(intDivide(a, 2))][0] + ((a & 1) == 0 ? -d : d);
    };
    StepAreaSeries.prototype.vx = function () {
        return 1;
    };
    StepAreaSeries.prototype.h0 = function (a, b, c, d, e, f, g, h) {
        var i = NaN;
        if (c >= 0 && c < b.count) {
            i = b.item(c);
        }
        var j = NaN;
        if (d >= 0 && d < b.count) {
            j = b.item(d);
        }
        if (f == 0) {
            return j;
        }
        if (e == b.count - 1) {
            return i;
        }
        if (isNaN_(j) && g != 0 && a <= 0.5 && !h) {
            return i;
        }
        if (isNaN_(i) && g != 0 && a >= 0.5 && !h) {
            return j;
        }
        if (a > 0.5) {
            return j;
        }
        return i;
    };
    StepAreaSeries.prototype.by = function () {
        if (this.bz == 0) {
            return 2;
        }
        else {
            return _super.prototype.by.call(this);
        }
    };
    StepAreaSeries.prototype.w6 = function (a, b) {
        var _this = this;
        _super.prototype.w6.call(this, a, b);
        var c = b.by;
        var d = b.bx;
        var e = this.getEffectiveViewport1(b);
        var f = typeCast(ISortingAxis_$type, this.yw) != null;
        var g = this.yw != null ? 0.5 * this.yw.getCategorySize(c, d, e) : 0;
        if (this.yw != null && this.yw.ch) {
            g = -g;
        }
        var h = a.f.count * 2;
        var i = new List$1(Array_$type, 2, h);
        this.vv.a2(this, this.wf(), runOn(this, this.vg), this.wo(b), this.wp(b));
        var j = false;
        var k = this.vv.b;
        if (k != null) {
            j = true;
        }
        for (var l = 0; l < h; l++) {
            var m = new Array(4);
            m[0] = this.zh(l, false, a, g, f);
            m[1] = a.f._inner[(intDivide(l, 2))][1];
            m[2] = this.zh(l, true, a, g, f);
            m[3] = a.f._inner[(intDivide(l, 2))][2];
            i.add(m);
        }
        var n = this.vw.cu.d;
        if (j) {
            var o = new ScalerParams(0, b.by, b.bx, this.yw.ch, e);
            this.w2(i, -1, this.valueColumn.count, this.yw, o, b.q);
        }
        var p = typeCast(StepAreaSeriesView.$, b);
        var q = p.ds;
        var r = p.dt;
        var s = p.dq;
        var t = p.dr;
        this.vv.ad(q, true, false, true, true);
        this.vv.ad(r, true, false, true, true);
        this.vv.ad(s, false, true, false, false);
        this.vv.ad(t, false, true, false, false);
        if (b.cy(a)) {
            p.dg(h, i, false, n, this.hk, function (u, v, w, x, y) { return _this.yc(u, 2 * a.f.count, b); }, 1, this.xf(i, i.count - 1, b.bx, b.by, true));
            b.c1(a);
        }
        var u = this.fetchYAxis();
        p.dq._opacity = this.vv.j * this.hg;
        p.dr._opacity = 0.5 * this.vv.j * this.hg;
    };
    Object.defineProperty(StepAreaSeries.prototype, "useHighMarkerFidelity", {
        get: function () {
            return this.wj;
        },
        enumerable: false,
        configurable: true
    });
    StepAreaSeries.$t = markType(StepAreaSeries, 'StepAreaSeries', HorizontalAnchoredCategorySeries.$);
    return StepAreaSeries;
}(HorizontalAnchoredCategorySeries));
export { StepAreaSeries };
/**
 * @hidden
 */
var StepAreaSeriesView = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(StepAreaSeriesView, _super);
    function StepAreaSeriesView(a) {
        var _this = _super.call(this, a) || this;
        _this.dd = null;
        _this.dl = new Path();
        _this.dn = new Path();
        _this.dm = new Path();
        _this.dp = new Path();
        _this.dh = new Path();
        _this.dj = new Path();
        _this.di = new Path();
        _this.dk = new Path();
        _this.dd = a;
        return _this;
    }
    StepAreaSeriesView.prototype.au = function () {
        _super.prototype.au.call(this);
        if (!this.q) {
            this.dd.ub = Defaults.c;
        }
    };
    Object.defineProperty(StepAreaSeriesView.prototype, "dq", {
        get: function () {
            return this.dl;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(StepAreaSeriesView.prototype, "ds", {
        get: function () {
            return this.dn;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(StepAreaSeriesView.prototype, "dr", {
        get: function () {
            return this.dm;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(StepAreaSeriesView.prototype, "dt", {
        get: function () {
            return this.dp;
        },
        enumerable: false,
        configurable: true
    });
    StepAreaSeriesView.prototype.de = function () {
        this.dl.an = null;
        this.dm.an = null;
        this.dn.an = null;
        this.dp.an = null;
        this.as();
    };
    StepAreaSeriesView.prototype.df = function (a, b, c, d, e, f, g) {
        this.df(a, b, c, d, e, f, g);
    };
    StepAreaSeriesView.prototype.dg = function (a, b, c, d, e, f, g, h) {
        this.dd.zf.a = typeCast(ISortingAxis_$type, this.cw.fetchXAxis()) !== null ? true : false;
        this.dd.zf.j(this.dl, this.dn, this.dm, this.dp, a, b, c, d, e, f, g, h);
        this.as();
    };
    StepAreaSeriesView.prototype.be = function () {
        _super.prototype.be.call(this);
        this.dh.an = this.dl.an;
        this.dj.an = this.dn.an;
        this.di.an = this.dm.an;
        this.dk.an = this.dp.an;
        var a = this.br();
        this.dh._fill = a;
        this.dh._opacity = 1;
        this.di._fill = a;
        this.di._opacity = 1;
        this.dj._stroke = a;
        this.dj.ad = this.e.hl + 3;
        this.dk._stroke = a;
        this.dk.ad = this.e.hl + 3;
    };
    StepAreaSeriesView.prototype.a8 = function (a, b) {
        _super.prototype.a8.call(this, a, b);
        if (b) {
            a.t(this.dh);
            a.t(this.di);
            a.t(this.dj);
            a.t(this.dk);
        }
        else {
            a.t(this.dl);
            a.t(this.dm);
            a.t(this.dn);
            a.t(this.dp);
        }
    };
    StepAreaSeriesView.prototype.an = function (a) {
        _super.prototype.an.call(this, a);
        this.e.a9.exportPathData(a, this.dn, "lowerShape", ["Lower"]);
        this.e.a9.exportPathData(a, this.dp, "upperShape", ["Upper", "Main"]);
        this.e.a9.exportPathData(a, this.dm, "translucentShape", ["Translucent"]);
        this.e.a9.exportPathData(a, this.dl, "fillShape", ["Fill"]);
    };
    StepAreaSeriesView.$t = markType(StepAreaSeriesView, 'StepAreaSeriesView', AnchoredCategorySeriesView.$);
    return StepAreaSeriesView;
}(AnchoredCategorySeriesView));
export { StepAreaSeriesView };

==> igniteui-angular-charts-17.3.0.tgz: package/esm5/lib/StepAreaSeries_combined.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { HorizontalAnchoredCategorySeries } from "./HorizontalAnchoredCategorySeries";
import { CategoryLineRasterizer } from "./CategoryLineRasterizer";
import { typeCast, Array_$type, runOn, markType } from "igniteui-angular-core";
import { ISortingAxis_$type } from "./ISortingAxis";
import { List$1 } from "igniteui-angular-core";
import { Path } from "igniteui-angular-core";
import { ScalerParams } from "./ScalerParams";
import { intDivide, isNaN_ } from "igniteui-angular-core";
import { AnchoredCategorySeriesView } from "./AnchoredCategorySeriesView";
import { Defaults } from "./Defaults";
/**
 * @hidden
 */
var StepAreaSeries = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(StepAreaSeries, _super);
    function StepAreaSeries() {
        var _this = _super.call(this) || this;
        _this.zg = null;
        _this.zg = new CategoryLineRasterizer();
        _this.ab = StepAreaSeries.$;
        return _this;
    }
    StepAreaSeries.prototype.bc = function () {
        return new StepAreaSeries();
    };
    StepAreaSeries.prototype.cd = function () {
        return new StepAreaSeriesView(this);
    };
    StepAreaSeries.prototype.o2 = function (a) {
        _super.prototype.o2.call(this, a);
        this.zh = a;
    };
    StepAreaSeries.prototype.get_ea = function () {
        return true;
    };
    StepAreaSeries.prototype.get_d9 = function () {
        return true;
    };
    StepAreaSeries.prototype.get_ff = function () {
        return true;
    };
    StepAreaSeries.prototype.get_ez = function () {
        return true;
    };
    StepAreaSeries.prototype.cj = function () {
        if (this.ck == 0) {
            return 2;
        }
        return _super.prototype.cj.call(this);
    };
    StepAreaSeries.prototype.preferredCategoryMode = function (a) {
        return typeCast(ISortingAxis_$type, a) !== null ? 0 : 1;
    };
    StepAreaSeries.prototype.nk = function (a, b) {
        _super.prototype.nk.call(this, a, b);
        var c = b;
        c.de();
    };
    StepAreaSeries.prototype.zi = function (a, b, c, d, e) {
        if (b) {
            if (e) {
                if ((a & 1) == 0 || ((intDivide(a, 2)) + 1) >= c.f.count) {
                    return c.f._inner[(intDivide(a, 2))][0];
                }
                return c.f._inner[(intDivide(a, 2)) + 1][0];
            }
            return c.f._inner[(intDivide(a, 2))][0] + ((a & 1) == 1 ? -d : d);
        }
        if (e) {
            if ((a & 1) == 0 || ((intDivide(a, 2)) + 1) >= c.f.count) {
                return c.f._inner[(intDivide(a, 2))][0];
            }
            return c.f._inner[(intDivide(a, 2)) + 1][0];
        }
        return c.f._inner[(intDivide(a, 2))][0] + ((a & 1) == 0 ? -d : d);
    };
    StepAreaSeries.prototype.vy = function () {
        return 1;
    };
    StepAreaSeries.prototype.h0 = function (a, b, c, d, e, f, g, h) {
        var i = NaN;
        if (c >= 0 && c < b.count) {
            i = b.item(c);
        }
        var j = NaN;
        if (d >= 0 && d < b.count) {
            j = b.item(d);
        }
        if (f == 0) {
            return j;
        }
        if (e == b.count - 1) {
            return i;
        }
        if (isNaN_(j) && g != 0 && a <= 0.5 && !h) {
            return i;
        }
        if (isNaN_(i) && g != 0 && a >= 0.5 && !h) {
            return j;
        }
        if (a > 0.5) {
            return j;
        }
        return i;
    };
    StepAreaSeries.prototype.bu = function () {
        if (this.bv == 0) {
            return 2;
        }
        else {
            return _super.prototype.bu.call(this);
        }
    };
    StepAreaSeries.prototype.w7 = function (a, b) {
        var _this = this;
        _super.prototype.w7.call(this, a, b);
        var c = b.by;
        var d = b.bx;
        var e = this.getEffectiveViewport1(b);
        var f = typeCast(ISortingAxis_$type, this.yx) != null;
        var g = this.yx != null ? 0.5 * this.yx.getCategorySize(c, d, e) : 0;
        if (this.yx != null && this.yx.ch) {
            g = -g;
        }
        var h = a.f.count * 2;
        var i = new List$1(Array_$type, 2, h);
        this.vw.a2(this, this.wg(), runOn(this, this.vh), this.wp(b), this.wq(b));
        var j = false;
        var k = this.vw.b;
        if (k != null) {
            j = true;
        }
        for (var l = 0; l < h; l++) {
            var m = new Array(4);
            m[0] = this.zi(l, false, a, g, f);
            m[1] = a.f._inner[(intDivide(l, 2))][1];
            m[2] = this.zi(l, true, a, g, f);
            m[3] = a.f._inner[(intDivide(l, 2))][2];
            i.add(m);
        }
        var n = this.vx.cu.d;
        if (j) {
            var o = new ScalerParams(0, b.by, b.bx, this.yx.ch, e);
            this.w3(i, -1, this.valueColumn.count, this.yx, o, b.q);
        }
        var p = typeCast(StepAreaSeriesView.$, b);
        var q = p.ds;
        var r = p.dt;
        var s = p.dq;
        var t = p.dr;
        this.vw.ad(q, true, false, true, true);
        this.vw.ad(r, true, false, true, true);
        this.vw.ad(s, false, true, false, false);
        this.vw.ad(t, false, true, false, false);
        if (b.cy(a)) {
            p.dg(h, i, false, n, this.hk, function (u, v, w, x, y) { return _this.yd(u, 2 * a.f.count, b); }, 1, this.xg(i, i.count - 1, b.bx, b.by, true));
            b.c1(a);
        }
        var u = this.fetchYAxis();
        p.dq._opacity = this.vw.j * this.hg;
        p.dr._opacity = 0.5 * this.vw.j * this.hg;
    };
    Object.defineProperty(StepAreaSeries.prototype, "useHighMarkerFidelity", {
        get: function () {
            return this.wk;
        },
        enumerable: false,
        configurable: true
    });
    StepAreaSeries.$t = markType(StepAreaSeries, 'StepAreaSeries', HorizontalAnchoredCategorySeries.$);
    return StepAreaSeries;
}(HorizontalAnchoredCategorySeries));
export { StepAreaSeries };
/**
 * @hidden
 */
var StepAreaSeriesView = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(StepAreaSeriesView, _super);
    function StepAreaSeriesView(a) {
        var _this = _super.call(this, a) || this;
        _this.dd = null;
        _this.dl = new Path();
        _this.dn = new Path();
        _this.dm = new Path();
        _this.dp = new Path();
        _this.dh = new Path();
        _this.dj = new Path();
        _this.di = new Path();
        _this.dk = new Path();
        _this.dd = a;
        return _this;
    }
    StepAreaSeriesView.prototype.au = function () {
        _super.prototype.au.call(this);
        if (!this.q) {
            this.dd.uc = Defaults.c;
        }
    };
    Object.defineProperty(StepAreaSeriesView.prototype, "dq", {
        get: function () {
            return this.dl;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(StepAreaSeriesView.prototype, "ds", {
        get: function () {
            return this.dn;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(StepAreaSeriesView.prototype, "dr", {
        get: function () {
            return this.dm;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(StepAreaSeriesView.prototype, "dt", {
        get: function () {
            return this.dp;
        },
        enumerable: false,
        configurable: true
    });
    StepAreaSeriesView.prototype.de = function () {
        this.dl.an = null;
        this.dm.an = null;
        this.dn.an = null;
        this.dp.an = null;
        this.as();
    };
    StepAreaSeriesView.prototype.df = function (a, b, c, d, e, f, g) {
        this.df(a, b, c, d, e, f, g);
    };
    StepAreaSeriesView.prototype.dg = function (a, b, c, d, e, f, g, h) {
        this.dd.zg.a = typeCast(ISortingAxis_$type, this.cw.fetchXAxis()) !== null ? true : false;
        this.dd.zg.j(this.dl, this.dn, this.dm, this.dp, a, b, c, d, e, f, g, h);
        this.as();
    };
    StepAreaSeriesView.prototype.be = function () {
        _super.prototype.be.call(this);
        this.dh.an = this.dl.an;
        this.dj.an = this.dn.an;
        this.di.an = this.dm.an;
        this.dk.an = this.dp.an;
        var a = this.br();
        this.dh._fill = a;
        this.dh._opacity = 1;
        this.di._fill = a;
        this.di._opacity = 1;
        this.dj._stroke = a;
        this.dj.ad = this.e.hl + 3;
        this.dk._stroke = a;
        this.dk.ad = this.e.hl + 3;
    };
    StepAreaSeriesView.prototype.a8 = function (a, b) {
        _super.prototype.a8.call(this, a, b);
        if (b) {
            a.t(this.dh);
            a.t(this.di);
            a.t(this.dj);
            a.t(this.dk);
        }
        else {
            a.t(this.dl);
            a.t(this.dm);
            a.t(this.dn);
            a.t(this.dp);
        }
    };
    StepAreaSeriesView.prototype.an = function (a) {
        _super.prototype.an.call(this, a);
        this.e.a5.exportPathData(a, this.dn, "lowerShape", ["Lower"]);
        this.e.a5.exportPathData(a, this.dp, "upperShape", ["Upper", "Main"]);
        this.e.a5.exportPathData(a, this.dm, "translucentShape", ["Translucent"]);
        this.e.a5.exportPathData(a, this.dl, "fillShape", ["Fill"]);
    };
    StepAreaSeriesView.$t = markType(StepAreaSeriesView, 'StepAreaSeriesView', AnchoredCategorySeriesView.$);
    return StepAreaSeriesView;
}(AnchoredCategorySeriesView));
export { StepAreaSeriesView };
